# Generated by Django 3.0 on 2020-11-06 16:49

from django.db import migrations, models
import ripple.validators


class Migration(migrations.Migration):

    dependencies = [
        ('ripple', '0005_user_is_guest'),
    ]

    operations = [
        migrations.AlterField(
            model_name='user',
            name='is_guest',
            field=models.BooleanField(default=False, help_text="Designates whether this user should be treated as Guest. Guest accounts are created for users who don't want to or can't create an account so it is created for them", verbose_name='guest'),
        ),
        migrations.AlterField(
            model_name='user',
            name='phone_number',
            field=models.CharField(blank=True, max_length=20, null=True, validators=[ripple.validators.validate_gb_phone_number]),
        ),
    ]
