# Generated by Django 3.0 on 2020-10-29 16:14

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ripple', '0004_auto_20200402_1411'),
    ]

    operations = [
        migrations.AddField(
            model_name='user',
            name='is_guest',
            field=models.BooleanField(default=False, help_text="Designates whether this user should be treated as Guest. Guest accounts are created for users who don'twant to or can't create an account so it is created for them", verbose_name='guest'),
        ),
    ]
